| area | auth_name | code | deprecated | name | projection_method_name
--- | --- | --- | --- | --- | --- | ---
0 | Europe - between 12°E and 18°E onshore and off... | EPSG | 23033 | False | ED50 / UTM zone 33N | Transverse Mercator
1 | Italy - onshore and offshore - east of 12°E in... | EPSG | 3004 | False | Monte Mario / Italy zone 2 | Transverse Mercator
2 | Europe - European Union (EU) countries and can... | EPSG | 3034 | False | ETRS89-extended / LCC Europe | Lambert Conic Conformal (2SP)
3 | Europe - European Union (EU) countries and can... | EPSG | 3035 | False | ETRS89-extended / LAEA Europe | Lambert Azimuthal Equal Area
4 | Italy - onshore and offshore - east of 12°E in... | EPSG | 3065 | False | IGM95 / UTM zone 33N | Transverse Mercator
... | ... | ... | ... | ... | ... | ...
20 | Italy - onshore and offshore. | EPSG | 7794 | False | RDN2008 / Italy zone (E-N) | Transverse Mercator
21 | Italy - onshore and offshore. | EPSG | 7795 | False | RDN2008 / Zone 12 (E-N) | Transverse Mercator
22 | World. | EPSG | 8857 | False | WGS 84 / Equal Earth Greenwich | Equal Earth
23 | World centred on the Americas. | EPSG | 8858 | False | WGS 84 / Equal Earth Americas | Equal Earth
24 | World centred on Asia-Pacific. | EPSG | 8859 | False | WGS 84 / Equal Earth Asia-Pacific | Equal Earth